==> dialob-client-api-3.0.2-sources.jar: io/dialob/client/api/DialobStore.java <==
package io.dialob.client.api;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

import javax.annotation.Nonnull;

import org.immutables.value.Value;

import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;

import io.dialob.api.form.FormEntity;
import io.smallrye.mutiny.Uni;


public interface DialobStore {
  HistoryQuery history();
  Uni<StoreEntity> create(CreateStoreEntity newType);
  Uni<StoreEntity> update(UpdateStoreEntity updateType);
  Uni<StoreEntity> delete(DeleteStoreEntity deleteType);
  Uni<List<StoreEntity>> batch(List<StoreCommand> batchType);
    
  QueryBuilder query();
  String getRepoName();
  String getHeadName();
  StoreRepoBuilder repo();
  
  
  interface HistoryQuery {
    Uni<HistoryEntity> get(@Nonnull String id, @Nonnull String rev);
  }
  
  interface StoreRepoBuilder {
    StoreRepoBuilder repoName(String repoName);
    StoreRepoBuilder headName(String headName);
    Uni<DialobStore> create();    
    DialobStore build();
    Uni<Boolean> createIfNot();
  }
  
  interface QueryBuilder {
    QueryBuilder id(@Nonnull String id);
    QueryBuilder rev(String rev);
    Uni<StoreEntity> findOne();
    Uni<StoreState> get();
  }


  
  @Value.Immutable @JsonSerialize(as = ImmutableStoreState.class) @JsonDeserialize(as = ImmutableStoreState.class)
  interface StoreState {
    Map<String, StoreEntity> getTags();
    Map<String, StoreEntity> getForms();
  }
  
  @Value.Immutable @JsonSerialize(as = ImmutableStoreEntity.class) @JsonDeserialize(as = ImmutableStoreEntity.class)
  interface StoreEntity extends Serializable {
    String getId();
    BodyType getBodyType();
    String getHash();
    String getBody();
  }
  
  @Value.Immutable @JsonDeserialize(as = ImmutableHistoryEntity.class) @JsonSerialize(as = ImmutableHistoryEntity.class)
  interface HistoryEntity {
    String getId();
    FormEntity getBodyType();
    List<DetachedEntity> getBody();
  }
  
  @Value.Immutable @JsonDeserialize(as = ImmutableDetachedEntity.class) @JsonSerialize(as = ImmutableDetachedEntity.class)
  interface DetachedEntity {
    String getHash();
    LocalDateTime getCreated();
    FormEntity getBody();
  }
  
  
  
  interface StoreCommand extends Serializable {
    String getId();
    BodyType getType();
  }

  @Value.Immutable @JsonSerialize(as = ImmutableUpdateStoreEntity.class) @JsonDeserialize(as = ImmutableUpdateStoreEntity.class)
  interface UpdateStoreEntity extends StoreCommand {
    FormEntity getBody();
  }

  @Value.Immutable @JsonSerialize(as = ImmutableCreateStoreEntity.class) @JsonDeserialize(as = ImmutableCreateStoreEntity.class)
  interface CreateStoreEntity extends StoreCommand {
    FormEntity getBody();
  }
  
  @Value.Immutable @JsonSerialize(as = ImmutableDeleteStoreEntity.class) @JsonDeserialize(as = ImmutableDeleteStoreEntity.class)
  interface DeleteStoreEntity extends StoreCommand { }  

  
  enum BodyType { FORM, TAG }
  enum BodyStatus { OK, ERROR }
  
  @Value.Immutable @JsonSerialize(as = ImmutableBodySource.class) @JsonDeserialize(as = ImmutableBodySource.class)
  interface BodySource extends Serializable {
    String getId();
    String getHash();
    BodyType getBodyType();
    String getValue();
  }
  
}

==> dialob-client-api-3.0.3-sources.jar: io/dialob/client/api/DialobStore.java <==
package io.dialob.client.api;

import java.io.Serializable;
import java.util.List;
import java.util.Map;
import java.util.function.Supplier;

import javax.annotation.Nullable;

import org.immutables.value.Value;

import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;

import io.dialob.client.api.DialobDocument.DocumentType;
import io.smallrye.mutiny.Uni;


public interface DialobStore {
  Uni<StoreEntity> create(CreateStoreEntity newType);
  Uni<StoreEntity> update(UpdateStoreEntity updateType);
  Uni<StoreEntity> delete(DeleteStoreEntity deleteType);
  Uni<List<StoreEntity>> batch(List<StoreCommand> batchType);
    
  QueryBuilder query();
  String getRepoName();
  String getHeadName();
  StoreRepoBuilder repo();
  
  
  interface StoreRepoBuilder {
    StoreRepoBuilder repoName(String repoName);
    StoreRepoBuilder headName(String headName);
    Uni<DialobStore> create();    
    DialobStore build();
    Uni<Boolean> createIfNot();
  }
  
  interface QueryBuilder {
    Uni<StoreState> get();
    Uni<StoreEntity> get(String id);
  }

  @Value.Immutable @JsonSerialize(as = ImmutableStoreState.class) @JsonDeserialize(as = ImmutableStoreState.class)
  interface StoreState {
    Map<String, StoreEntity> getRevs();
    Map<String, StoreEntity> getForms();
    Map<String, StoreEntity> getTags();    
  }
  
  @Value.Immutable @JsonSerialize(as = ImmutableStoreEntity.class) @JsonDeserialize(as = ImmutableStoreEntity.class)
  interface StoreEntity extends Serializable {
    String getId();
    String getVersion();
    DocumentType getBodyType();
    String getBody();
  }
  
  
  interface StoreCommand extends Serializable {
    DocumentType getBodyType();
  }

  @Value.Immutable @JsonSerialize(as = ImmutableUpdateStoreEntity.class) @JsonDeserialize(as = ImmutableUpdateStoreEntity.class)
  interface EmptyCommand extends StoreCommand {
    String getId();
    String getDescription();
  }
  
  @Value.Immutable @JsonSerialize(as = ImmutableUpdateStoreEntity.class) @JsonDeserialize(as = ImmutableUpdateStoreEntity.class)
  interface UpdateStoreEntity extends StoreCommand {
    String getId();
    String getVersion();
    String getBody();
  }

  @Value.Immutable @JsonSerialize(as = ImmutableCreateStoreEntity.class) @JsonDeserialize(as = ImmutableCreateStoreEntity.class)
  interface CreateStoreEntity extends StoreCommand {
    @Nullable String getId(); // in case not provided, auto generated
    @Nullable String getVersion(); // in case not provided, auto generated
    String getBody();
  }
  
  @Value.Immutable @JsonSerialize(as = ImmutableDeleteStoreEntity.class) @JsonDeserialize(as = ImmutableDeleteStoreEntity.class)
  interface DeleteStoreEntity extends StoreCommand {
    String getId();
    String getVersion();
  }
  
  @Value.Immutable @JsonSerialize(as = ImmutableStoreExceptionMsg.class)
  interface StoreExceptionMsg {
    String getId();
    String getValue();
    List<String> getArgs();
  }
  
  @FunctionalInterface
  interface DialobCredsSupplier extends Supplier<DialobCreds> {}
  
  @Value.Immutable
  interface DialobCreds {
    String getUser();
    String getEmail();
  } 
}
